.. _getting_started:

Getting Started
========================

This section is the entry point for setting up spyctl and getting a basic understanding of its usage.

.. toctree::
   :maxdepth: 1

   install
   /tutorials/spyctl_basics




